import type { CreateSelfServiceCitizenRunner } from '../models/CreateSelfServiceCitizenRunner';
import type { CreateSelfServiceRunner } from '../models/CreateSelfServiceRunner';
import type { ResponseScanStation } from '../models/ResponseScanStation';
import type { ResponseSelfServiceOrganisation } from '../models/ResponseSelfServiceOrganisation';
import type { ResponseSelfServiceRunner } from '../models/ResponseSelfServiceRunner';
import type { ResponseSelfServiceScan } from '../models/ResponseSelfServiceScan';
export declare class RunnerSelfService {
    /**
     * Get
     * Lists all information about yourself. <br> Please provide your runner jwt(that code we gave you during registration) for auth. <br> If you lost your jwt/personalized link please use the forgot endpoint.
     * @param jwt
     * @returns ResponseSelfServiceRunner
     * @throws ApiError
     */
    static runnerSelfServiceControllerGet(jwt: string): Promise<ResponseSelfServiceRunner>;
    /**
     * Remove
     * Deletes all information about yourself. <br> Please provide your runner jwt(that code we gave you during registration) for auth. <br> If you lost your jwt/personalized link please use the forgot endpoint.
     * @param jwt
     * @param force
     * @returns ResponseSelfServiceRunner
     * @throws ApiError
     */
    static runnerSelfServiceControllerRemove(jwt: string, force?: boolean): Promise<ResponseSelfServiceRunner>;
    /**
     * Get scans
     * Lists all your (runner) scans. <br> Please provide your runner jwt(that code we gave you during registration) for auth. <br> If you lost your jwt/personalized link please contact support.
     * @param jwt
     * @returns ResponseSelfServiceScan
     * @throws ApiError
     */
    static runnerSelfServiceControllerGetScans(jwt: string): Promise<Array<ResponseSelfServiceScan>>;
    /**
     * Get station me
     * Lists basic information about the station whose token got provided. <br> This includes it's associated track.
     * @returns ResponseScanStation
     * @throws ApiError
     */
    static runnerSelfServiceControllerGetStationMe(): Promise<ResponseScanStation>;
    /**
     * Request new token
     * Use this endpoint to reuqest a new selfservice magic-login-link to be sent to your mail address (rate limited to one mail every 15mins).
     * @param mail
     * @param locale
     * @returns any Successful response
     * @throws ApiError
     */
    static runnerSelfServiceControllerRequestNewToken(mail?: string, locale?: string): Promise<any>;
    /**
     * Register runner
     * Create a new selfservice runner in the citizen org. <br> This endpoint shoud be used to allow "everyday citizen" to register themselves. <br> You have to provide a mail address, b/c the future we'll implement email verification.
     * @param locale
     * @param requestBody CreateSelfServiceCitizenRunner
     * @returns ResponseSelfServiceRunner
     * @throws ApiError
     */
    static runnerSelfServiceControllerRegisterRunner(locale?: string, requestBody?: CreateSelfServiceCitizenRunner): Promise<ResponseSelfServiceRunner>;
    /**
     * Register organization runner
     * Create a new selfservice runner in a provided org. <br> The orgs get provided and authorized via api tokens that can be optained via the /organizations endpoint.
     * @param token
     * @param locale
     * @param requestBody CreateSelfServiceRunner
     * @returns ResponseSelfServiceRunner
     * @throws ApiError
     */
    static runnerSelfServiceControllerRegisterOrganizationRunner(token: string, locale?: string, requestBody?: CreateSelfServiceRunner): Promise<ResponseSelfServiceRunner>;
    /**
     * Get selfservice org
     * Get the basic info and teams for a org.
     * @param token
     * @returns ResponseSelfServiceOrganisation
     * @throws ApiError
     */
    static runnerSelfServiceControllerGetSelfserviceOrg(token: string): Promise<ResponseSelfServiceOrganisation>;
}
